==> eam-wshub-proxyclient-11.4-0-sources.jar: net/datastream/schemas/mp_fields/AUDITSETUPTRIGGERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for AUDITSETUPTRIGGERID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="AUDITSETUPTRIGGERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AUDITSETUPTRIGGERCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AUDITSETUPTRIGGERTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AUDITSETUPTRIGGERID_Type", propOrder = {
    "auditsetuptriggercode",
    "auditsetuptriggertext"
})
public class AUDITSETUPTRIGGERID_Type {

    @XmlElement(name = "AUDITSETUPTRIGGERCODE")
    protected Double auditsetuptriggercode;
    @XmlElement(name = "AUDITSETUPTRIGGERTEXT")
    protected String auditsetuptriggertext;

    /**
     * Gets the value of the auditsetuptriggercode property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getAUDITSETUPTRIGGERCODE() {
        return auditsetuptriggercode;
    }

    /**
     * Sets the value of the auditsetuptriggercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setAUDITSETUPTRIGGERCODE(Double value) {
        this.auditsetuptriggercode = value;
    }

    /**
     * Gets the value of the auditsetuptriggertext property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAUDITSETUPTRIGGERTEXT() {
        return auditsetuptriggertext;
    }

    /**
     * Sets the value of the auditsetuptriggertext property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAUDITSETUPTRIGGERTEXT(String value) {
        this.auditsetuptriggertext = value;
    }

}

==> eam-wshub-proxyclient-11.4-7-sources.jar: net/datastream/schemas/mp_fields/AUDITSETUPTRIGGERID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour AUDITSETUPTRIGGERID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="AUDITSETUPTRIGGERID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AUDITSETUPTRIGGERCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}AUDITSETUPTRIGGERTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "AUDITSETUPTRIGGERID_Type", propOrder = {
    "auditsetuptriggercode",
    "auditsetuptriggertext"
})
public class AUDITSETUPTRIGGERID_Type {

    @XmlElement(name = "AUDITSETUPTRIGGERCODE")
    protected Double auditsetuptriggercode;
    @XmlElement(name = "AUDITSETUPTRIGGERTEXT")
    protected String auditsetuptriggertext;

    /**
     * Obtient la valeur de la propriété auditsetuptriggercode.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getAUDITSETUPTRIGGERCODE() {
        return auditsetuptriggercode;
    }

    /**
     * Définit la valeur de la propriété auditsetuptriggercode.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setAUDITSETUPTRIGGERCODE(Double value) {
        this.auditsetuptriggercode = value;
    }

    /**
     * Obtient la valeur de la propriété auditsetuptriggertext.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getAUDITSETUPTRIGGERTEXT() {
        return auditsetuptriggertext;
    }

    /**
     * Définit la valeur de la propriété auditsetuptriggertext.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setAUDITSETUPTRIGGERTEXT(String value) {
        this.auditsetuptriggertext = value;
    }

}
